.\" @(#)$RCSfile: lcg-cp.man,v $ $Revision: 1.22 $ $Date: 2009/11/19 13:58:41 $ CERN Jean-Philippe Baud
.\" Copyright (C) 2005 by CERN
.\" All rights reserved
.\"
.TH "LCG-CP" "1" "$Date: 2009/11/19 13:58:41 $" "LCG_UTIL" "User Commands"

.SH "NAME"
lcg-cp - copy files from/to/between Storage Element(s),
without registering anything in the file catalog.

.SH "SYNOPSIS"
.B lcg-cp
[
.BI --config " config_file"
] [
.B -h,--help
] [
.BI -n " nbstreams"
] [
.BI -D,--defaultsetype " defaulttype"
] [
.BI -T,--srcsetype " srctype"
] [
.BI -U,--dstsetype " dsttype"
] [
.BI -s,--sst " src_spacetokendesc"
] [
.BI -S,--dst " dest_spacetokendesc"
] [
.BI  --connect-timeout " conntimeout"
] [
.BI  --sendreceive-timeout " sndtimeout"
] [
.BI  --bdii-timeout " bdiitimeout"
] [
.BI  --srm-timeout " srmtimeout"
] [
.BI --vo " virtual_organization"
] [
.BI --checksum-type " cksmtype"
] [
.B --checksum
] [
.B -b,--nobdii
] [
.B -v,--verbose
] [
.B --version
] [
.BI --src-protocols " protocol_list"
] [
.BI --dst-protocols " protocol_list"
]
.I src_file
.I dest_file

.SH "DESCRIPTION"
.B lcg-cp
copies a Grid file to a local destination, or copie a local file to a SE (without
registering it in a file catalog). If you specify a given command line option
multiple times, the command takes into account only the very last one so that in a script, you can
override a particular option in a pre-set option set (like gcc does).
.TP
.I src_file
specifies the source file name. The protocol can be LFN, GUID, SURL, GSIFTP or
local file. An SURL scheme can be
.B sfn:
for a classical SE or
.BR srm: .
.TP
.I dest_file
specifies the destination. The protocol can be SURL, GSIFTP or local file. An SURL
scheme can be
.B sfn:
for a classical SE or
.BR srm: .
SURL can be used only if
.I src_file
is GSIFTP or local file. In that case, the SURL will NOT be registered in a file
catalog.
.TP
.I nbstreams
specifies the number of parallel streams (default 1).
.TP
.I defaulttype
specifies the default SE type you want to use. Possible values are
.BR none ,
.BR se ,
.BR srmv1 ,
.BR srmv2 ,
for respectively no default type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will use another type.
.TP
.I srctype
specifies the SE type you want to use for the source file. Possible values are
.BR none ,
.BR se ,
.BR srmv1 ,
.BR srmv2 ,
for respectively no type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will fail.
.TP
.I dsttype
specifies the SE type you want to use for the destination file. Possible values are
.BR none ,
.BR se ,
.BR srmv1 ,
.BR srmv2 ,
for respectively no type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will fail.
.TP
.I src_spacetokendesc
specifies the space token to use with
.I src_file
.TP
.I dest_spacetokendesc
specifies the space token to use with
.I dest_file
.TP
.I conntimeout
Sets the connect timeout, used when connecting to a remote host. The connection will be aborted
if the remote host doesn't reply after
.I conntimeout
seconds. Default: 60 seconds.
.TP
.I sndtimeout
Sets the send/receive data timeout, used when transferring data to/from a remote host. The connection will be aborted
if no data is transfered after
.I sndtimeout
seconds. Default: 0 (blocking).
.TP
.I bdiitimeout
Sets the BDII timeout, used when searching information into BDII. The connection will be aborted
if the search is longer than
.I bdiitimeout
seconds. Default: 60 seconds.
.TP
.I srmtimeout
Sets the SRM timeout, used when doing an asynchronous SRM request. The request will be aborted
if it is still queued after
.I srmtimeout
seconds. Default: 3600 seconds (1 hour).
.TP
.I vo
specifies the Virtual Organization the user belongs to. If it is not  specified,
the  environment  variable  LCG_GFAL_VO will be used.
.TP
.I conf_file
This argument is currently ignored.
.TP
.I cksmtype
is the checksum type (algorithm) to use. Possible values (case insensitive) are:
.RS
.TP 1.5i
.B NONE
No checksum verification
.TP
.B CRC32
CRC32 algorithm will be used
.TP
.B ADLER32
Adler32 algorithm will be used
.TP
.B MD5
MD5 algorithm will be used
.TP
.B SHA1
SHA-1 algorithm will be used
.RE
.TP
.I protocol_list
A comma-separated list of protocols (for example
.BR protocol1,protocol2
)
.TP
.B --checksum
If this flag is present, verification of data integrity between source and destination files will be dine using default checksum
algorithm (Adler32). In case of failure, the destination won't be removed, but an error message will be printed.
.TP
.B -b,--nobdii
If this flag is present, it means that you don't want to make BDII calls to get SE type. So, you must provide the type of the SE
for srm: arguments, and full endpoint in SURLs. For SE type,
.I defaulttype
can be used (it will be used for both source and destination).
.TP
.B -v,--verbose
Verbose mode. You can specify it twice for extra verbose mode.
.TP
.B --src-protocols
The ordered list of transfer protocols to help TURL construction. The list is passed
to the SE, it should pick up an appropriate one and construct source TURL-s according to it.
Ignored if the source file does not follow the SURL scheme.
.TP
.B --dst-protocols
The ordered list of transfer protocols to help TURL construction. The list is passed
to the SE, it should pick up an appropriate one and construct destination TURL-s according to it.
Ignored if the destination file does not follow the SURL scheme.

.SH "NOTE"
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I --nobdii
option is used.
To use the RLS as catalog instead of the LFC, the environment variable
LCG_CATALOG_TYPE must explicitely be set to "edg". By default, it is set to "lfc".

.SH "EXAMPLES"
.nf
.ft CW
	lcg-cp --verbose --vo dteam file:///etc/group srm://lxbra1910.cern.ch/dpm/cern.ch/home/dteam/1/test
	lcg-cp --verbose --vo dteam srm://lxbra1910.cern.ch/dpm/cern.ch/home/dteam/1/test srm://lxbra1910.cern.ch/dpm/cern.ch/home/dteam/1/test_new
	lcg-cp --verbose --vo dteam --nobdii -D srmv2 srm://lxbra1910.cern.ch:8446/srm/managerv2?SFN=/dpm/cern.ch/home/dteam/1/test file://home/user/test_copy
	lcg-cp --vo dteam lfn:/grid/dteam/tests/testjpb33 file:/tmp/toto
.ft
.fi


.SH "EXIT STATUS"
This program returns 0 if the operation was successful or >0 if the operation
failed.

.SH "SEE ALSO"
.BR lcg-aa (1),
.BR lcg-cp (1),
.BR lcg-cr (1),
.BR lcg-del (1),
.BR lcg-getturls (1),
.BR lcg-gt (1),
.BR lcg-la (1),
.BR lcg-lg (1),
.BR lcg-lr (1),
.BR lcg-ls (1),
.BR lcg-ra (1),
.BR lcg-rep (1),
.BR lcg-rf (1),
.BR lcg-sd (1),
.BR lcg-stmd (1),
.BR lcg-uf (1)
