.\" @(#)$RCSfile: lcg_la.man,v $ $Revision: 1.10 $ $Date: 2008/05/07 12:40:28 $ CERN Jean-Philippe Baud
.\" Copyright (C) 2005 by CERN
.\" All rights reserved
.\"
.TH LCG_LA 3 "$Date: 2008/05/07 12:40:28 $" LCG_UTIL "Library Functions"

.SH NAME
lcg_la \- get the list of aliases for a given LFN, GUID or SURL

.SH SYNOPSIS
\fB#include "lcg_util.h"\fR
.sp
.BI "int lcg_la (char *" file ,
.BI "char *" vo ,
.BI "char *" conf_file ,
.BI "int " insecure ,
.BI "char ***" lfns );
.sp
.BI "int lcg_lax (char *" file ,
.BI "char *" vo ,
.BI "char *" conf_file ,
.BI "int " insecure ,
.BI "char ***" lfns ,
.BI "char *" errbuf ,
.BI "int " errbufsz );
.sp
.BI "int lcg_la2 (char *" file ,
.BI "int " nobdii ,
.BI "char *" vo ,
.BI "char ***" lfns ,
.BI "char *" errbuf ,
.BI "int " errbufsz );

.SH DESCRIPTION
.B lcg_la
gets the list of aliases for a given LFN, GUID or SURL.
.TP
.I file
specifies the Logical File Name, the Grid Unique IDentifier or the Site URL.
An SURL scheme can be
.B sfn:
for a classical SE or
.BR srm: .
.TP
.I nobdii
If set to a non-zero value, it means that you don't want to make BDII calls to get LFC endpoint.
So, you have to define the environment variable 'LFC_HOST'.
.TP 
.I vo
specifies the Virtual Organization the user belongs to. If it is not specified,
the environment variable LCG_GFAL_VO will be used.
.TP
.I conf_file
This argument is actually ignored.
.TP
.I insecure 
This argument is actually ignored.
.TP
.I lfns
will be set by the routine to the address of the array of pointers to the
aliases. The application should free both the logical file names and the array
of pointers.
.TP
.I errbuf
specifies a buffer of size
.I errbufsz
to receive detailed error messages. If this pointer is NULL, the message goes
to stderr. The pointer should not be NULL if the application is a daemon or is
multi-threaded.

.SH NOTE
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I nobdii
is set to a non-zero value.
To use the RLS as catalog instead of the LFC, the environment variable
LCG_CATALOG_TYPE must explicitely be set to "edg". By default, it is set to "lfc".

.SH RETURN VALUE
This routine returns 0 if the operation was successful or -1 if the operation
failed. In the latter case,
.B errno
is set appropriately.

.SH ERRORS
.TP 1.3i
.B ENOENT
The named file does not exist.
.TP
.B EFAULT
.IR file ,
.I vo
or
.I lfns
is an invalid pointer.
.TP
.B EINVAL
.I file
has an invalid syntax.
.TP
.B ECOMM
Communication error.
.TP
.B ENAMETOOLONG
.I vo
is too long.
.TP
.B EPROTONOSUPPORT
Access method not supported.

.SH FILES
.B /opt/lcg/include/lcg_util.h
.TP
.B /opt/lcg/lib/liblcg_util.so

.SH SEE ALSO
.BR lcg_aa (3),
.BR lcg_cp (3),
.BR lcg_cr (3),
.BR lcg_del (3),
.BR lcg_gt (3),
.BR lcg_la (3),
.BR lcg_lg (3),
.BR lcg_lr (3),
.BR lcg_ra (3),
.BR lcg_rep (3),
.BR lcg_rf (3),
.BR lcg_sd (3),
.BR lcg_stmd (3),
.BR lcg_uf (3)
