.\" @(#)$RCSfile: lcg_sd.man,v $ $Revision: 1.7 $ $Date: 2008/05/07 12:40:28 $ CERN Jean-Philippe Baud
.\" Copyright (C) 2005 by CERN
.\" All rights reserved
.\" 
.TH "LCG_SD" "3" "$Date: 2008/05/07 12:40:28 $" "LCG_UTIL" "Library Functions"

.SH "NAME"
lcg_sd \- set file status to "Done" for a given SURL in a specified request

.SH "SYNOPSIS"
\fB#include "lcg_util.h"\fR
.sp
.BI "int lcg_sd (char *" surl ,
.BI "int " reqid ,
.BI "int " fileid ,
.BI "char *" token ,
.BI "int " oflag );
.sp
.BI "int lcg_sdt (char *" surl ,
.BI "int " reqid ,
.BI "int " fileid ,
.BI "char *" token ,
.BI "int " oflag ,
.BI "int " timeout );
.sp
.BI "int lcg_sdx (char *" surl ,
.BI "int " reqid ,
.BI "int " fileid ,
.BI "char *" token ,
.BI "int " oflag ,
.BI "char *" errbuf ,
.BI "int " errbufsz );
.sp
.BI "int lcg_sdxt (char *" surl ,
.BI "int " reqid ,
.BI "int " fileid ,
.BI "char *" token ,
.BI "int " oflag ,
.BI "char *" errbuf ,
.BI "int " errbufsz,
.BI "int " timeout);
.sp
.BI "int lcg_sd3 (char *" surl ,
.BI "int " nobdii ,
.BI "int " reqid ,
.BI "int " fileid ,
.BI "char *" token ,
.BI "char *" errbuf ,
.BI "int " errbufsz,
.BI "int " timeout);

.SH "DESCRIPTION"
.B lcg_sd
sets file status to "Done" for a given SURL in a specified request.
This is only meaningful if the space is managed by an SRM.
.TP 
.I surl
specifies the Site URL. An SURL starts with
.BR srm: .
.TP
.I nobdii
If set to a non-zero value, it means that you don't want to make BDII calls to get SE type. So, you must provide full endpoint in SURLs.
The SE type is deduced from arguments. If you specify
.I reqtoken
(not NULL) it is a  SRMv2  endpoint. Else it is a SRMv1 endpoint.
.TP 
.I reqid
is the request identifier returned by an SRM v1 get/put request or
.BR lcg_gt .
.TP 
.I fileid
is the file ordinal returned by an SRM v1 get/put request or
.BR lcg_gt .
.TP 
.I token
is the token returned by an SRM v2 get/put request or
.BR lcg_gt .
.TP 
.I oflag
must be zero if the request was an SRM get or if
.B lcg_gt
was called, it must be non\-zero if the request was an SRM put.
.TP 
.I timeout
specifies the value of timeout (default 0).
.TP 
.I errbuf
specifies a buffer of size
.I errbufsz
to receive detailed error messages. If this pointer is NULL, the message goes
to stderr. The pointer should not be NULL if the application is a daemon or is
multi\-threaded.

.SH "NOTE"
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I nobdii
is set to a non-zero value.

.SH "RETURN VALUE"
This routine returns 0 if the operation was successful or \-1 if the operation
failed. In the latter case,
.B errno
is set appropriately.

.SH "ERRORS"
.TP 1.3i
.B ENOENT
The named file does not exist.
.TP 
.B EACCES
Permission denied.
.TP 
.B EFAULT
One of the arguments is an invalid pointer.
.TP 
.B EINVAL
.I surl
has an invalid syntax.
.TP 
.B ECOMM
Communication error.
.TP 
.B EPROTONOSUPPORT
Access method not supported.

.SH "FILES"
.B /opt/lcg/include/lcg_util.h
.TP 
.B /opt/lcg/lib/liblcg_util.so

.SH "SEE ALSO"
.BR lcg_aa (3),
.BR lcg_cp (3),
.BR lcg_cr (3),
.BR lcg_del (3),
.BR lcg_gt (3),
.BR lcg_la (3),
.BR lcg_lg (3),
.BR lcg_lr (3),
.BR lcg_ra (3),
.BR lcg_rep (3),
.BR lcg_rf (3),
.BR lcg_sd (3),
.BR lcg_stmd (3),
.BR lcg_uf (3)
