/*
 * Authors: Zsolt Molnar <zsolt.molnar@cern.ch, http://www.zsoltmolnar.hu>
 *
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Test if the logic recognizes unknown protocols of wrongly formatted
 * protocol lists in the transfetParameters property of PrepareToGet.
 */
#include "lcg_util.h"
#include "gfal_api.h"
#include "gfal_dependencies.h"
#include "globus_dependencies.h"
#include <assert.h>
#include <errno.h>
#include <string.h>

#include "lcg_unit_testsuite.h"

#define GFAL_RETURN_CODE_OK 0
#define GFAL_RETURN_CODE_ERROR -1
#define INVALID_ADDRESS (void*)(0x1)

/* The dependency injection comes here. This function replaces the production
 * version SOAP calls so that no network operation, server, etc be required.
 * The function directly produces and returns the SRM response objects.
 *
 * This is the "SOAP call" for the srmPrepareToGet operation. */
static int _74459_lcg_gt_segfault__gfal_turlsfromsurls(
    gfal_internal req, char *errbuf, int errbufsz)
{
    return GFAL_RETURN_CODE_OK;
}

static int _74459_lcg_gt_segfault__gfal_init(
    gfal_request req, gfal_internal *gfal, char *errbuf, int errbufsz)
{
    return GFAL_RETURN_CODE_OK;
}

static int _74459_lcg_gt_segfault__gfal_get_results(
    gfal_internal req, gfal_filestatus **results)
{
    *results = malloc(sizeof(gfal_filestatus));
    (*results)[0].status = 0;
    (*results)[0].turl = NULL;
    return 1;
}

/* Inject the dependencies. Replace the SOAP callers to the test ones. */
static void _setup_callers()
{
    lcg_gfal_functions.call_gfal_turlsfromsurls = _74459_lcg_gt_segfault__gfal_turlsfromsurls;
    lcg_gfal_functions.call_gfal_init = _74459_lcg_gt_segfault__gfal_init;
    lcg_gfal_functions.call_gfal_get_results = _74459_lcg_gt_segfault__gfal_get_results;
}

char * lcg_test__74459_lcg_gt_segfault()
{
    int errbufsz = 1024;
    char errbuf[1024];
    int res = 0xFFFF;

    errno = 0;
    _setup_callers();

    res = lcg_gt4(
        INVALID_ADDRESS, TYPE_SRMv2, TYPE_SRMv2, 0, INVALID_ADDRESS, INVALID_ADDRESS, 
        INVALID_ADDRESS, INVALID_ADDRESS, INVALID_ADDRESS, INVALID_ADDRESS, 
        errbuf, errbufsz, 0, INVALID_ADDRESS
    );

    LCG_TEST_EQUAL(ENODATA, errno);
    LCG_TEST_EQUAL(GFAL_RETURN_CODE_ERROR, res);
    LCG_TEST_EQUAL_STRING("Server did not return a TURL!\n", errbuf);
    
    return NULL;
}

#undef __CALL_TEST
